@@ -98,7 +98,7 @@ import {{ Optional, Seq, Tuple, ListTuple, unit, bool, int8, int16, int32, int64
         for namespace in self.generator.namespaces_to_import.iter() {
             writeln!(
                 self.out,
-                "import * as {} from '../{}.ts';\n",
+                "import * as {} from '../{}/mod.ts';\n",
                 namespace.to_camel_case(),
                 namespace
             )?;
